@@ -1,4 +1,3 @@
-import glob
 import json
 import os
 import re
@@ -12,7 +11,7 @@ from langchain_huggingface import HuggingFaceEmbeddings
 from openai import OpenAI
 from pydantic import field_validator, BaseModel, ValidationError
 from tqdm import tqdm
-from .utils import normalize_street_name
+from .utils import load_checkpoint, normalize_street_name, save_checkpoint
 
 load_dotenv()
 
@@ -54,9 +53,9 @@ class TaxonomyModel(BaseModel):
         """
         fields = info.data.get("discrete_fields", [])
         taxonomy = info.data.get("taxonomy", [])
-        if set(v.keys()) != set(fields):
+        if len(v) != len(fields):
             raise ValueError(
-                f"The keys in the list {fields} do not exactly match the keys in the dictionary {list(v.keys())}"
+                f"The keys in the list ({len(fields)}) do not exactly match the keys in the dictionary ({len(v)})"
             )
         elif not set(v.values()).issubset(set(taxonomy + ["null"] + [None])):
             raise ValueError(
@@ -99,28 +98,6 @@ class TranslationModel(BaseModel):
             )
         return v
 
-def deprecate_cache_file(file: str = None):
-    """
-    Delete a specific cache file or all temporary files in the current directory.
-    
-    Args:
-        file: Optional specific file path to delete. If None, deletes all .tmp files.
-    """
-    if os.path.isfile(file):
-        os.remove(file)
-        print(f"Removed file: {file}")
-    else:
-        files = glob.glob("*.tmp")
-        if files:
-            for f in files:
-                try:
-                    os.remove(f)
-                    print(f"Removed file: {f}")
-                except Exception as e:
-                    print(f"Cannot remove {f}: {e}")
-        else:
-            print("No files to remove")
-
 def propose_taxonomy(field: str, description: str, discrete_fields: list[str] = None) -> list[str]:
     """
     Generate a taxonomy proposal using an OpenAI model.
@@ -340,32 +317,6 @@ def reasoning(client, part, taxonomy, classification_description):
     partial_result = json.loads(res)
     return partial_result
 
-def load_checkpoint(tmp_file: str):
-    """
-    Load a previous classification checkpoint from a temporary file.
-    
-    Args:
-        tmp_file: Path to the checkpoint file
-    
-    Returns:
-        Dictionary of previously classified items or empty dict if file doesn't exist
-    """
-    if os.path.exists(tmp_file):
-        with open(tmp_file, "r", encoding="utf-8") as f:
-            return json.load(f)
-    return {}
-
-def save_checkpoint(tmp_file, data):
-    """
-    Save current classification progress to a temporary file.
-    
-    Args:
-        tmp_file: Path where to save the checkpoint
-        data: Dictionary of field-to-classification mappings to persist
-    """
-    with open(tmp_file, "w", encoding="utf-8") as f:
-        json.dump(data, f, ensure_ascii=False, indent=2)
-
 def apply_taxonomy_reasoning(discrete_fields: list[str], taxonomy: list[str],
                              classification_description: str, hash_file: str = None):
     """
@@ -464,7 +415,7 @@ def analyze_text_field(field_name: str, field_value: str, task: Literal["label",
         r"<[^>]+>.*?</[^>]+>\s*", "", response.choices[0].message.content,
         flags=re.DOTALL).strip()
 
-def translate_taxonomy_reasoning(src_lang, dest_lang, headers):
+def translate_headers_reasoning(src_lang, dest_lang, headers):
     """
     Translate column headers from one language to another.
     
@@ -525,3 +476,27 @@ def web_search(query):
             })
 
     return results
+
+def classify_element(element, mapping_example):
+    client = OpenAI(base_url=SERVER_URL, api_key=API_KEY)
+
+
+    message = f"""
+    You are an assistant that classifies an item into one of the possible classifications provided.
+    This are the examples, where the key is the element and the value is the classification:
+    {mapping_example}
+    You must reply only with the name of the classification.
+    """
+
+    response = client.chat.completions.create(
+        model=MODEL_NAME,
+        messages=[
+            {"role": "system",
+             "content": message
+            },
+            {"role": "user", "content": f"Now, for this new item, '{element}', choose one of the existing classifications."}
+#{json.dumps(headers, ensure_ascii=False)}"}
+        ]
+    )
+    classification = re.sub(r"<[^>]+>.*?</[^>]+>\s*", "", response.choices[0].message.content, flags=re.DOTALL).strip()
+    return classification
